From nacc@us.ibm.com Mon Aug 15 11:35:04 2005
Date: Mon, 15 Aug 2005 11:30:11 -0700
From: Nishanth Aravamudan <nacc@us.ibm.com>
To: greg@kroah.com, dbrownell@users.sourceforge.net, weissg@vienna.at,
        dignome@gmail.com
Cc: akpm@osdl.org
Subject: drivers/usb: fix-up schedule_timeout() usage
Message-ID: <20050815183011.GI2854@us.ibm.com>

Description: Use schedule_timeout_{,un}interruptible() instead of
set_current_state()/schedule_timeout() to reduce kernel size.

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/usb/class/audio.c       |   12 ++++++++----
 drivers/usb/host/ehci-hcd.c     |    3 +--
 drivers/usb/host/ohci-hcd.c     |    3 +--
 drivers/usb/serial/cypress_m8.c |    3 +--
 drivers/usb/serial/pl2303.c     |    3 +--
 5 files changed, 12 insertions(+), 12 deletions(-)

--- gregkh-2.6.orig/drivers/usb/class/audio.c	2005-08-28 16:41:01.000000000 -0700
+++ gregkh-2.6/drivers/usb/class/audio.c	2005-09-12 11:01:58.000000000 -0700
@@ -631,8 +631,10 @@ static void usbin_stop(struct usb_audiod
 	i = u->flags;
 	spin_unlock_irqrestore(&as->lock, flags);
 	while (i & (FLG_URB0RUNNING|FLG_URB1RUNNING|FLG_SYNC0RUNNING|FLG_SYNC1RUNNING)) {
-		set_current_state(notkilled ? TASK_INTERRUPTIBLE : TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
+		if (notkilled)
+			schedule_timeout_interruptible(1);
+		else
+			schedule_timeout_uninterruptible(1);
 		spin_lock_irqsave(&as->lock, flags);
 		i = u->flags;
 		spin_unlock_irqrestore(&as->lock, flags);
@@ -1102,8 +1104,10 @@ static void usbout_stop(struct usb_audio
 	i = u->flags;
 	spin_unlock_irqrestore(&as->lock, flags);
 	while (i & (FLG_URB0RUNNING|FLG_URB1RUNNING|FLG_SYNC0RUNNING|FLG_SYNC1RUNNING)) {
-		set_current_state(notkilled ? TASK_INTERRUPTIBLE : TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
+		if (notkilled)
+			schedule_timeout_interruptible(1);
+		else
+			schedule_timeout_uninterruptible(1);
 		spin_lock_irqsave(&as->lock, flags);
 		i = u->flags;
 		spin_unlock_irqrestore(&as->lock, flags);
--- gregkh-2.6.orig/drivers/usb/host/ehci-hcd.c	2005-09-12 11:01:57.000000000 -0700
+++ gregkh-2.6/drivers/usb/host/ehci-hcd.c	2005-09-12 11:01:58.000000000 -0700
@@ -1147,8 +1147,7 @@ rescan:
 	case QH_STATE_UNLINK:		/* wait for hw to finish? */
 idle_timeout:
 		spin_unlock_irqrestore (&ehci->lock, flags);
-		set_current_state (TASK_UNINTERRUPTIBLE);
-		schedule_timeout (1);
+		schedule_timeout_uninterruptible(1);
 		goto rescan;
 	case QH_STATE_IDLE:		/* fully unlinked */
 		if (list_empty (&qh->qtd_list)) {
--- gregkh-2.6.orig/drivers/usb/host/ohci-hcd.c	2005-08-28 16:41:01.000000000 -0700
+++ gregkh-2.6/drivers/usb/host/ohci-hcd.c	2005-09-12 11:01:58.000000000 -0700
@@ -382,8 +382,7 @@ sanitize:
 			goto sanitize;
 		}
 		spin_unlock_irqrestore (&ohci->lock, flags);
-		set_current_state (TASK_UNINTERRUPTIBLE);
-		schedule_timeout (1);
+		schedule_timeout_uninterruptible(1);
 		goto rescan;
 	case ED_IDLE:		/* fully unlinked */
 		if (list_empty (&ed->td_list)) {
--- gregkh-2.6.orig/drivers/usb/serial/cypress_m8.c	2005-09-12 10:47:36.000000000 -0700
+++ gregkh-2.6/drivers/usb/serial/cypress_m8.c	2005-09-12 11:01:58.000000000 -0700
@@ -610,8 +610,7 @@ static void cypress_close(struct usb_ser
 		timeout = max((HZ*2560)/bps,HZ/10);
 	else
 		timeout = 2*HZ;
-	set_current_state(TASK_INTERRUPTIBLE);
-	schedule_timeout(timeout);
+	schedule_timeout_interruptible(timeout);
 
 	dbg("%s - stopping urbs", __FUNCTION__);
 	usb_kill_urb (port->interrupt_in_urb);
--- gregkh-2.6.orig/drivers/usb/serial/pl2303.c	2005-09-12 10:47:36.000000000 -0700
+++ gregkh-2.6/drivers/usb/serial/pl2303.c	2005-09-12 11:01:58.000000000 -0700
@@ -652,8 +652,7 @@ static void pl2303_close (struct usb_ser
 		timeout = max((HZ*2560)/bps,HZ/10);
 	else
 		timeout = 2*HZ;
-	set_current_state(TASK_INTERRUPTIBLE);
-	schedule_timeout(timeout);
+	schedule_timeout_interruptible(timeout);
 
 	/* shutdown our urbs */
 	dbg("%s - shutting down urbs", __FUNCTION__);
